@@ -11,6 +11,7 @@ with 'Venus::Role::Boxable';
 with 'Venus::Role::Tryable';
 with 'Venus::Role::Catchable';
 with 'Venus::Role::Comparable';
+with 'Venus::Role::Deferrable';
 with 'Venus::Role::Dumpable';
 with 'Venus::Role::Digestable';
 with 'Venus::Role::Doable';
@@ -171,6 +172,8 @@ L<Venus::Role::Catchable>
 
 L<Venus::Role::Comparable>
 
+L<Venus::Role::Deferrable>
+
 L<Venus::Role::Digestable>
 
 L<Venus::Role::Doable>
