@@ -62,7 +62,7 @@ sub assertion {
 
   my $assert = $self->SUPER::assertion;
 
-  $assert->clear->array;
+  $assert->clear->expression('arrayref');
 
   return $assert;
 }
